===============================
months
===============================

.. image:: https://img.shields.io/travis/kstark/months.svg
        :target: https://travis-ci.org/kstark/months

.. image:: https://img.shields.io/pypi/v/months.svg
        :target: https://pypi.python.org/pypi/months

.. image:: https://readthedocs.org/projects/months/badge/?version=latest
        :target: https://readthedocs.org/projects/months/?badge=latest
        :alt: Documentation Status


Python library for representing specific months

* Free software: MIT license
* Documentation: https://months.readthedocs.org.

Features
--------

- Represent specific months along with their years
- Convert to and from native datetime and date objects
- Convenient math operations for adding / subtracting month intervals
- Convenient operations for displaying months
